pub struct AssetsBasePath(pub PathBuf);Expand description
Resource storing the base assets path for converting absolute paths to relative
Tuple Fields
0: PathBufImplementations
Sourceimpl AssetsBasePath
impl AssetsBasePath
pub fn new(path: impl Into<PathBuf>) -> Self
Sourcepub fn to_relative(&self, absolute_path: &Path) -> PathBuf
pub fn to_relative(&self, absolute_path: &Path) -> PathBuf
Convert an absolute path to a path relative to the assets folder. Returns the relative path if the absolute path is within the assets folder, otherwise returns the original path (kept for backward compatibility).
Sourcepub fn to_relative_checked(
&self,
absolute_path: &Path,
) -> Result<PathBuf, PathError>
pub fn to_relative_checked( &self, absolute_path: &Path, ) -> Result<PathBuf, PathError>
Convert an absolute path to a path relative to the assets folder. Returns an error if the file doesn’t exist or is outside the assets directory.
Sourcepub fn is_inside_assets(&self, absolute_path: &Path) -> bool
pub fn is_inside_assets(&self, absolute_path: &Path) -> bool
Check if a path is inside the assets directory